@@ -119,7 +119,7 @@ use std::path::Path;
 // regex that tries to parse printf's format placeholders
 // see: https://docs.microsoft.com/en-us/cpp/c-runtime-library/format-specification-syntax-printf-and-wprintf-functions?view=msvc-160
 static RE_PRINTF: Lazy<Regex> =
-    Lazy::new(|| Regex::new(r"%([-+#])?(\d+)?(\.\d+)?([dis@xXf])|[^%]+|%%|%$").unwrap());
+    Lazy::new(|| Regex::new(r#"%([-+#])?(\d+)?(\.\d+)?([dis@xXf])|%%|%$|"|[^%"]+"#).unwrap());
 static RE_LANG: Lazy<Regex> = Lazy::new(|| Regex::new(r"(\w+)(-(\w+))?").unwrap());
 static RE_SECTION: Lazy<Regex> = Lazy::new(|| Regex::new(r"^\s*\[([^\]]+)\]").unwrap());
 static RE_KEY_VALUE: Lazy<Regex> =
@@ -453,6 +453,8 @@ impl TwineFormatter {
                     out.push_str("}");
                 } else if &caps[0] == "%%" {
                     out.push_str("%");
+                } else if &caps[0] == "\"" {
+                    out.push_str("\\\"");
                 } else {
                     out.push_str(&caps[0]);
                 }
@@ -483,7 +485,7 @@ impl TwineFormatter {
             write!(
                 f,
                 r#"
-                $crate::Lang::{}({}) => format!({:?} $(, $fmt_args)*),
+                $crate::Lang::{}({}) => format!("{}" $(, $fmt_args)*),
                 "#,
                 lang,
                 region.as_deref().unwrap_or("_"),
@@ -495,7 +497,7 @@ impl TwineFormatter {
             write!(
                 f,
                 r#"
-                _ => format!({:?} $(, $fmt_args)*),
+                _ => format!("{}" $(, $fmt_args)*),
                 "#,
                 default_out,
             )?;
